import logging

import pdfplumber
import typer

from aquaparser.parsers.parser import MeasurementParser

logging.basicConfig(level=logging.INFO)

typer_app = typer.Typer(help='Aqua-Parser manager.')


@typer_app.command(help='Start parser.')
def run(filename: str):
    measurement = MeasurementParser()
    doc = pdfplumber.open(filename)
    measurement.parse(doc)


if __name__ == '__main__':
    typer_app()



import logging

import pdfplumber

from aquaparser.parsers import title_parser, toc_parser
from aquaparser.schemas import Measurement, MeasurementTOC

logger = logging.getLogger(__name__)


class MeasurementParser:

    def __init__(self):
        self.title_parser = title_parser.TitleParser()
        self.toc_parser = toc_parser.TocParser()

    def parse(self, doc: pdfplumber):
        measurement = Measurement(
            title=self.title_parser.parse(doc),
            toc=self.toc_parser.parse(doc),
        )
        logger.info(measurement.title)
        self.log_toc(measurement.toc)
        return measurement

    def log_toc(self, table: list[MeasurementTOC]):
        for num, row in enumerate(table):
            smd = row.smd.replace('\n', ' ')
            row_num = num + 1
            control_string = f'{row_num}: smd = {smd}; status = {row.status}'
            logger.info(control_string)



from datetime import datetime
from typing import Any

import pdfplumber

from aquaparser.schemas import MeasurementTitle


class TitleParser:

    def parse(self, doc: pdfplumber):
        page = doc.pages[:1]
        table = page[0].extract_tables({
            'edge_min_length': 15,  # this param get clean title table default 3
        })
        return self._clean_title(table)

    def _clean_title(self, table: list[list[Any]]) -> MeasurementTitle:
        measure_title, measure_description = table

        measure_date = datetime.strptime(measure_description[2][1], '%d.%m.%Y %H:%M')

        return MeasurementTitle(
            measurement_object=measure_title[1][1],
            project=measure_description[0][1],
            report_date=measure_date,
            responsible_person=measure_description[3][1],
        )



from dataclasses import dataclass
from datetime import datetime
from typing import Optional


@dataclass
class MeasurementTitle:
    measurement_object: str
    project: str
    report_date: datetime
    responsible_person: str


@dataclass
class MeasurementTOC:
    smd: str
    status: Optional[str]
    value_description: Optional[str]
    single_value: Optional[str]
    trial_object: Optional[str]


@dataclass
class Measurement:
    title: MeasurementTitle
    toc: list[MeasurementTOC]



from typing import Any

import pdfplumber

from aquaparser.schemas import MeasurementTOC

SMD_ERROR = ('SMD', None, '')


class TocParser:

    def parse(self, doc: pdfplumber, start: int = 2, finish: int = 3):
        return self._get_toc(
            doc=doc,
            start_page=start,
            finish_page=finish,
        )

    def _clean_toc(self, table: list[list[Any]]) -> list[MeasurementTOC]:
        new_table = []

        for row in table:
            smd, status, description, value, obj = row
            if smd in SMD_ERROR:
                continue

            measurement_toc = MeasurementTOC(
                smd=smd,
                status=status,
                value_description=description,
                single_value=value,
                trial_object=obj,
            )
            new_table.append(measurement_toc)

        return new_table

    def _get_toc(self, doc: pdfplumber, start_page: int, finish_page: int) -> list[MeasurementTOC]:
        pages = doc.pages[start_page:finish_page]
        toc_list = []

        for page in pages:
            table = page.extract_table({
                'edge_min_length': 200,  # this param get clean toc table default 3
            })

            valid_table = self._clean_toc(table)
            toc_list.extend(valid_table)

        return toc_list
